summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/popupmenueditor.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/popupmenueditor.h')
-rw-r--r--kdevdesigner/designer/popupmenueditor.h36
1 files changed, 19 insertions, 17 deletions
diff --git a/kdevdesigner/designer/popupmenueditor.h b/kdevdesigner/designer/popupmenueditor.h
index 8c024e34..29ffcf4c 100644
--- a/kdevdesigner/designer/popupmenueditor.h
+++ b/kdevdesigner/designer/popupmenueditor.h
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2003 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -34,13 +34,14 @@
class PopupMenuEditor;
class TQMenuItem;
-class PopupMenuEditorItem : public QObject
+class PopupMenuEditorItem : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
friend class PopupMenuEditor;
- PopupMenuEditorItem( PopupMenuEditor * menu = 0, TQObject * parent = 0, const char * name = 0 );
+ PopupMenuEditorItem( PopupMenuEditor * menu = 0, TQObject * tqparent = 0, const char * name = 0 );
public:
enum ItemType {
@@ -50,9 +51,9 @@ public:
};
PopupMenuEditorItem( TQAction * action, PopupMenuEditor * menu,
- TQObject * parent = 0, const char * name = 0 );
+ TQObject * tqparent = 0, const char * name = 0 );
PopupMenuEditorItem( PopupMenuEditorItem * item, PopupMenuEditor * menu,
- TQObject * parent = 0, const char * name = 0 );
+ TQObject * tqparent = 0, const char * name = 0 );
~PopupMenuEditorItem();
void init();
@@ -97,17 +98,18 @@ class TQLineEdit;
#include <tqpopupmenu.h>
-class PopupMenuEditor : public QWidget
+class PopupMenuEditor : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
friend class PopupMenuEditorItem;
friend class MenuBarEditor;
friend class Resource;
public:
- PopupMenuEditor( FormWindow * fw, TQWidget * parent = 0, const char * name = 0 );
- PopupMenuEditor( FormWindow * fw, PopupMenuEditor * menu, TQWidget * parent, const char * name = 0 );
+ PopupMenuEditor( FormWindow * fw, TQWidget * tqparent = 0, const char * name = 0 );
+ PopupMenuEditor( FormWindow * fw, PopupMenuEditor * menu, TQWidget * tqparent, const char * name = 0 );
~PopupMenuEditor();
void init();
@@ -115,8 +117,8 @@ public:
void insert( PopupMenuEditorItem * item, int index = -1 );
void insert( TQAction * action, int index = -1 );
void insert( TQActionGroup * actionGroup, int index = -1 );
- int find( const TQAction * action );
- int find( PopupMenuEditor * menu );
+ int tqfind( const TQAction * action );
+ int tqfind( PopupMenuEditor * menu );
int count();
PopupMenuEditorItem * at( int index );
PopupMenuEditorItem * at( TQPoint pos ) { return itemAt( pos.y() ); }
@@ -131,14 +133,14 @@ public:
void show();
void choosePixmap( int index = -1 );
void showLineEdit( int index = -1);
- void setAccelerator( int key, Qt::ButtonState state, int index = -1 );
+ void setAccelerator( int key, TQt::ButtonState state, int index = -1 );
FormWindow * formWindow() { return formWnd; }
bool isCreatingAccelerator() { return ( currentField == 2 ); }
TQPtrList<PopupMenuEditorItem> * items() { return &itemList; }
- TQWidget * parentEditor() { return parentMenu; }
+ TQWidget * tqparentEditor() { return tqparentMenu; }
signals:
void inserted( TQAction * );
@@ -151,7 +153,7 @@ public slots:
void paste() { paste( currentIndex ); }
void remove( int index );
- void remove( TQAction * a ) { remove( find( a ) ); }
+ void remove( TQAction * a ) { remove( tqfind( a ) ); }
void resizeToContents();
void showSubMenu();
@@ -210,7 +212,7 @@ private:
TQPtrList<PopupMenuEditorItem> itemList;
PopupMenuEditorItem addItem;
PopupMenuEditorItem addSeparator;
- TQWidget * parentMenu;
+ TQWidget * tqparentMenu;
int iconWidth;
int textWidth;
@@ -1,15 +1,15 @@
** Copyright (C) 2003 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the